aboutsummaryrefslogtreecommitdiffstats
path: root/src/components/script/dom/virtualmethods.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/script/dom/virtualmethods.rs')
-rw-r--r--src/components/script/dom/virtualmethods.rs14
1 files changed, 8 insertions, 6 deletions
diff --git a/src/components/script/dom/virtualmethods.rs b/src/components/script/dom/virtualmethods.rs
index aa1ac0313b9..9ebb9a336c4 100644
--- a/src/components/script/dom/virtualmethods.rs
+++ b/src/components/script/dom/virtualmethods.rs
@@ -60,18 +60,20 @@ pub trait VirtualMethods {
}
}
- /// Called when a Node is appended to a tree that is part of a Document.
- fn bind_to_tree(&self) {
+ /// Called when a Node is appended to a tree, where 'tree_in_doc' indicates
+ /// whether the tree is part of a Document.
+ fn bind_to_tree(&self, tree_in_doc: bool) {
match self.super_type() {
- Some(ref s) => s.bind_to_tree(),
+ Some(ref s) => s.bind_to_tree(tree_in_doc),
_ => (),
}
}
- /// Called when a Node is removed from a tree that is part of a Document.
- fn unbind_from_tree(&self) {
+ /// Called when a Node is removed from a tree, where 'tree_in_doc'
+ /// indicates whether the tree is part of a Document.
+ fn unbind_from_tree(&self, tree_in_doc: bool) {
match self.super_type() {
- Some(ref s) => s.unbind_from_tree(),
+ Some(ref s) => s.unbind_from_tree(tree_in_doc),
_ => (),
}
}